@@ -108,6 +108,9 @@ class BaseRiskAnalyzer(ABC):
             Dictionary containing risk analysis results
         """
         try:
+            if not self.llm_client:
+                return self._create_error_response("LLM client not configured")
+            
             prompt = self.get_analysis_prompt()
             # Format the prompt with the startup data
             full_prompt = prompt.format(startup_data=startup_data)
@@ -115,7 +118,9 @@ class BaseRiskAnalyzer(ABC):
             # Use the LLM client to generate analysis
             result = self.llm_client.predict(
                 system_message="You are an expert startup risk analyst. Maintain professional language and avoid inappropriate content. Focus strictly on business and financial risk assessment.",
-                user_message=full_prompt
+                user_message=full_prompt,
+                tool_name=f"{self.category_name}Analyzer",
+                method_name="analyze"
             )
             
             # Parse the response using the JSON extractor
