@@ -144,6 +144,116 @@ class UploadExtractor:
         except Exception as e:
             return f"Video analysis failed: {str(e)}"
 
+    def extract_document_vertexai(self, document_path: str) -> Dict[str, Any]:
+        """
+        Extract content from a document using Google Vertex AI.
+        
+        Args:
+            document_path: Path to the document file
+            
+        Returns:
+            Dictionary containing extracted content and metadata
+        """
+        try:
+            import os
+            from google.cloud import aiplatform
+            from google.protobuf import json_format
+            from google.protobuf.struct_pb2 import Value
+            
+            # Get configuration from environment variables
+            project_id = os.getenv("GOOGLE_CLOUD_PROJECT")
+            endpoint_id = os.getenv("VERTEX_AI_ENDPOINT_ID")
+            location = os.getenv("GOOGLE_CLOUD_LOCATION", "us-central1")
+            api_endpoint = os.getenv("VERTEX_AI_API_ENDPOINT", f"{location}-aiplatform.googleapis.com")
+            
+            if not project_id or not endpoint_id:
+                return {
+                    "success": False,
+                    "error": "Missing required environment variables: GOOGLE_CLOUD_PROJECT or VERTEX_AI_ENDPOINT_ID",
+                    "content": ""
+                }
+            
+            # Read document content
+            with open(document_path, 'rb') as file:
+                document_content = file.read()
+            
+            # Encode document content to base64 for Vertex AI
+            import base64
+            document_base64 = base64.b64encode(document_content).decode('utf-8')
+            
+            # Prepare instance for Vertex AI prediction
+            instance = {
+                "document": {
+                    "content": document_base64,
+                    "mime_type": self._guess_mime_from_extension(os.path.splitext(document_path)[1].lstrip('.'))
+                }
+            }
+            
+            # Initialize Vertex AI client
+            client_options = {"api_endpoint": api_endpoint}
+            client = aiplatform.gapic.PredictionServiceClient(client_options=client_options)
+            
+            # Convert instance to protobuf format
+            instances = [json_format.ParseDict(instance, Value())]
+            parameters_dict = {}
+            parameters = json_format.ParseDict(parameters_dict, Value())
+            
+            # Get endpoint path
+            endpoint = client.endpoint_path(
+                project=project_id, 
+                location=location, 
+                endpoint=endpoint_id
+            )
+            
+            # Make prediction request
+            response = client.predict(
+                endpoint=endpoint, 
+                instances=instances, 
+                parameters=parameters
+            )
+            
+            # Extract predictions
+            predictions = response.predictions
+            if predictions and len(predictions) > 0:
+                prediction = predictions[0]
+                
+                # Extract text content from prediction
+                extracted_text = ""
+                if hasattr(prediction, 'text'):
+                    extracted_text = prediction.text
+                elif isinstance(prediction, dict) and 'text' in prediction:
+                    extracted_text = prediction['text']
+                elif isinstance(prediction, dict) and 'content' in prediction:
+                    extracted_text = prediction['content']
+                else:
+                    # Try to extract any text content from the prediction
+                    extracted_text = str(prediction)
+                
+                return {
+                    "success": True,
+                    "content": extracted_text,
+                    "model_id": response.deployed_model_id,
+                    "metadata": {
+                        "project_id": project_id,
+                        "endpoint_id": endpoint_id,
+                        "location": location,
+                        "document_path": document_path
+                    }
+                }
+            else:
+                return {
+                    "success": False,
+                    "error": "No predictions returned from Vertex AI",
+                    "content": ""
+                }
+                
+        except Exception as e:
+            return {
+                "success": False,
+                "error": f"Vertex AI extraction failed: {str(e)}",
+                "content": ""
+            }
+
     def extract_documents(self, uploads: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         """
         Extract content from a list of uploaded local files.
